package
Version:
v0.0.0-...-61cd50e
Opens a new window with list of versions in this module.
Published: May 5, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Queue interface{}表示任何类型
func (q *Queue) Pop() interface{}
Pop 出队
func (q *Queue) Push(v interface{})
Push 入队
Source Files
¶
Click to show internal directories.
Click to hide internal directories.