package
Version:
v0.0.0-...-61cd50e
Opens a new window with list of versions in this module.
Published: May 5, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
Package tree 树结构相关包
给 package 的注释要有固定开头
同一个目录下的所有文件的 package 都一样
type Node struct {
Value int
Left, Right *Node
}
Node 树节点
/ 结构名,变量名,方法名首字母大写时,对其他包可见,即 public
func (node *Node) Print()
Print 打印 value 值
func (node *Node) Traverse()
Traverse 中序遍历打印
方法的注释要以方法名开头
public 的方法必须要有注释
Source Files
¶
Click to show internal directories.
Click to hide internal directories.